[cfe-commits] r105580 - in /cfe/trunk: include/clang/Frontend/FrontendAction.h include/clang/Frontend/FrontendActions.h lib/Frontend/ASTMerge.cpp lib/Frontend/FrontendAction.cpp

Daniel Dunbar daniel at zuster.org
Mon Jun 7 16:24:43 PDT 2010


Author: ddunbar
Date: Mon Jun  7 18:24:43 2010
New Revision: 105580

URL: http://llvm.org/viewvc/llvm-project?rev=105580&view=rev
Log:
Frontend: Rename hasASTSupport to hasASTFileSupport, which is more accurate.

Modified:
    cfe/trunk/include/clang/Frontend/FrontendAction.h
    cfe/trunk/include/clang/Frontend/FrontendActions.h
    cfe/trunk/lib/Frontend/ASTMerge.cpp
    cfe/trunk/lib/Frontend/FrontendAction.cpp

Modified: cfe/trunk/include/clang/Frontend/FrontendAction.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Frontend/FrontendAction.h?rev=105580&r1=105579&r2=105580&view=diff
==============================================================================
--- cfe/trunk/include/clang/Frontend/FrontendActions.h (original)
+++ cfe/trunk/include/clang/Frontend/FrontendActions.h Mon Jun  7 18:24:43 2010
@@ -87,7 +87,7 @@
 
   virtual void EndSourceFileAction();
 
-  virtual bool hasASTSupport() const { return false; }
+  virtual bool hasASTFileSupport() const { return false; }
 
 public:
   FixItAction();
@@ -101,7 +101,7 @@
 
   virtual bool usesCompleteTranslationUnit() { return false; }
 
-  virtual bool hasASTSupport() const { return false; }
+  virtual bool hasASTFileSupport() const { return false; }
 };
 
 class HTMLPrintAction : public ASTFrontendAction {
@@ -170,7 +170,7 @@
   virtual bool usesPreprocessorOnly() const;
   virtual bool usesCompleteTranslationUnit();
   virtual bool hasPCHSupport() const;
-  virtual bool hasASTSupport() const;
+  virtual bool hasASTFileSupport() const;
   virtual bool hasCodeCompletionSupport() const;
 };
 

Modified: cfe/trunk/lib/Frontend/ASTMerge.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/ASTMerge.cpp?rev=105580&r1=105579&r2=105580&view=diff
==============================================================================
--- cfe/trunk/lib/Frontend/ASTMerge.cpp (original)
+++ cfe/trunk/lib/Frontend/ASTMerge.cpp Mon Jun  7 18:24:43 2010
@@ -95,8 +95,8 @@
   return AdaptedAction->hasPCHSupport();
 }
 
-bool ASTMergeAction::hasASTSupport() const {
-  return AdaptedAction->hasASTSupport();
+bool ASTMergeAction::hasASTFileSupport() const {
+  return AdaptedAction->hasASTFileSupport();
 }
 
 bool ASTMergeAction::hasCodeCompletionSupport() const {

Modified: cfe/trunk/lib/Frontend/FrontendAction.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/FrontendAction.cpp?rev=105580&r1=105579&r2=105580&view=diff
==============================================================================
--- cfe/trunk/lib/Frontend/FrontendAction.cpp (original)
+++ cfe/trunk/lib/Frontend/FrontendAction.cpp Mon Jun  7 18:24:43 2010
@@ -43,7 +43,8 @@
   if (InputKind == IK_AST) {
     assert(!usesPreprocessorOnly() &&
            "Attempt to pass AST file to preprocessor only action!");
-    assert(hasASTSupport() && "This action does not have AST support!");
+    assert(hasASTFileSupport() &&
+           "This action does not have AST file support!");
 
     llvm::IntrusiveRefCntPtr<Diagnostic> Diags(&CI.getDiagnostics());
     std::string Error;





More information about the cfe-commits mailing list
--- cfe/trunk/include/clang/Frontend/FrontendAction.h (original)
+++ cfe/trunk/include/clang/Frontend/FrontendAction.h Mon Jun  7 18:24:43 2010
@@ -144,8 +144,8 @@
   /// hasPCHSupport - Does this action support use with PCH?
   virtual bool hasPCHSupport() const { return !usesPreprocessorOnly(); }
 
-  /// hasASTSupport - Does this action support use with AST files?
-  virtual bool hasASTSupport() const { return !usesPreprocessorOnly(); }
+  /// hasASTFileSupport - Does this action support use with AST files?
+  virtual bool hasASTFileSupport() const { return !usesPreprocessorOnly(); }
 
   /// hasCodeCompletionSupport - Does this action support use with code
   /// completion?

Modified: cfe/trunk/include/clang/Frontend/FrontendActions.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Frontend/FrontendActions.h?rev=105580&r1=105579&r2=105580&view=diff
==============================================================================